@@ -4,19 +4,21 @@
     Copyright (c) 2006 - 2008 John Tapsell <john.tapsell@kde.org>
     Copyright (c) 1999 - 2001 Chris Schlaeger <cs@kde.org>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License version 2 or at your option version 3 as published by
-    the Free Software Foundation.
+ This program is free software; you can redistribute it and/or
+ modify it under the terms of the GNU General Public License as
+ published by the Free Software Foundation; either version 2 of
+ the License or (at your option) version 3 or any later version
+ accepted by the membership of KDE e.V. (or its successor approved
+ by the membership of KDE e.V.), which shall act as a proxy 
+ defined in Section 14 of version 3 of the license.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ You should have received a copy of the GNU General Public License
+ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
     KSysGuard has been written with some source code and ideas from
     ktop (<1.0). Early versions of ktop have been written by Bernd
@@ -40,7 +42,7 @@
 #include <kedittoolbar.h>
 #include <kglobal.h>
 #include <kglobalsettings.h>
-#include <kicon.h>
+#include <QIcon>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <ksgrd/SensorAgent.h>
@@ -53,6 +55,7 @@
 #include <QSplitter>
 
 #include <config-workspace.h>
+#include <KFormat>
 #include "SensorBrowser.h"
 #include "Workspace.h"
 #include "WorkSheet.h"
@@ -111,32 +114,32 @@ TopLevel::TopLevel()
   // create actions for menu entries
   mRefreshTabAction = KStandardAction::redisplay(mWorkSpace,SLOT(refreshActiveWorksheet()),actionCollection());
   mNewWorksheetAction = actionCollection()->addAction("new_worksheet");
-  mNewWorksheetAction->setIcon(KIcon("tab-new"));
+  mNewWorksheetAction->setIcon(QIcon::fromTheme("tab-new"));
   connect(mNewWorksheetAction, SIGNAL(triggered(bool)), mWorkSpace, SLOT(newWorkSheet()));
   mInsertWorksheetAction = actionCollection()->addAction("import_worksheet");
-  mInsertWorksheetAction->setIcon(KIcon("document-open") );
+  mInsertWorksheetAction->setIcon(QIcon::fromTheme("document-open") );
   connect(mInsertWorksheetAction, SIGNAL(triggered(bool)), mWorkSpace, SLOT(importWorkSheet()));
   mTabExportAction = actionCollection()->addAction( "export_worksheet" );
-  mTabExportAction->setIcon( KIcon("document-save-as") );
+  mTabExportAction->setIcon( QIcon::fromTheme("document-save-as") );
   connect(mTabExportAction, SIGNAL(triggered(bool)), mWorkSpace, SLOT(exportWorkSheet()));
   mTabRemoveAction = actionCollection()->addAction( "remove_worksheet" );
-  mTabRemoveAction->setIcon( KIcon("tab-close") );
+  mTabRemoveAction->setIcon( QIcon::fromTheme("tab-close") );
   connect(mTabRemoveAction, SIGNAL(triggered(bool)), mWorkSpace, SLOT(removeWorkSheet()));
   mMonitorRemoteAction = actionCollection()->addAction( "connect_host" );
-  mMonitorRemoteAction->setIcon( KIcon("network-connect") );
+  mMonitorRemoteAction->setIcon( QIcon::fromTheme("network-connect") );
   connect(mMonitorRemoteAction, SIGNAL(triggered(bool)), SLOT(connectHost()));
   //knewstuff2 action
   mHotNewWorksheetAction = actionCollection()->addAction( "get_new_worksheet" );
-  mHotNewWorksheetAction->setIcon( KIcon("network-server") );
+  mHotNewWorksheetAction->setIcon( QIcon::fromTheme("network-server") );
   connect(mHotNewWorksheetAction, SIGNAL(triggered(bool)), mWorkSpace, SLOT(getHotNewWorksheet()));
   mHotNewWorksheetUploadAction = actionCollection()->addAction( "upload_worksheet" );
-  mHotNewWorksheetUploadAction->setIcon( KIcon("network-server") );
+  mHotNewWorksheetUploadAction->setIcon( QIcon::fromTheme("network-server") );
   connect(mHotNewWorksheetUploadAction, SIGNAL(triggered(bool)), mWorkSpace, SLOT(uploadHotNewWorksheet()));
 
   mQuitAction = NULL;
 
   mConfigureSheetAction = actionCollection()->addAction( "configure_sheet" );
-  mConfigureSheetAction->setIcon( KIcon("configure") );
+  mConfigureSheetAction->setIcon( QIcon::fromTheme("configure") );
   connect(mConfigureSheetAction, SIGNAL(triggered(bool)), SLOT(configureCurrentSheet()));
 
   retranslateUi();
@@ -379,9 +382,9 @@ bool TopLevel::queryClose()
   if ( !mWorkSpace->saveOnQuit() )
     return false;
 
-  KConfigGroup cg( KGlobal::config(), "MainWindow" );
+  KConfigGroup cg( KSharedConfig::openConfig(), "MainWindow" );
   saveProperties( cg );
-  KGlobal::config()->sync();
+  KSharedConfig::openConfig()->sync();
 
   return true;
 }
@@ -454,8 +457,8 @@ void TopLevel::answerReceived( int id, const QList<QByteArray> &answerList )
       mUsedApplication = answer.toLongLong();
       //Use a multi-length string
       s = i18nc( "Arguments are formatted byte sizes (used/total)", "Memory: %1 / %2" "\xc2\x9c" "Mem: %1 / %2" "\xc2\x9c" "Mem: %1" "\xc2\x9c" "%1",
-                 KGlobal::locale()->formatByteSize( mUsedApplication*1024),
-                 KGlobal::locale()->formatByteSize( (mFree+mUsedTotal)*1024 ) );
+                 KFormat().formatByteSize( mUsedApplication*1024),
+                 KFormat().formatByteSize( (mFree+mUsedTotal)*1024 ) );
       sbMemTotal->setText( s );
       break;
 
@@ -483,8 +486,8 @@ void TopLevel::setSwapInfo( qlonglong used, qlonglong free, const QString & )
     msg = i18n( " No swap space available " );
   else {
     msg = i18nc( "Arguments are formatted byte sizes (used/total)", "Swap: %1 / %2" "\xc2\x9c" "Swap: %1" "\xc2\x9c" "%1" ,
-                 KGlobal::locale()->formatByteSize( used*1024 ),
-                 KGlobal::locale()->formatByteSize( (free+used)*1024) );
+                 KFormat().formatByteSize( used*1024 ),
+                 KFormat().formatByteSize( (free+used)*1024) );
   }
 
   sbSwapTotal->setText( msg );
@@ -563,7 +566,7 @@ extern "C" Q_DECL_EXPORT int kdemain( int argc, char** argv )
 
 
   // create top-level widget
-  Toplevel->readProperties( KConfigGroup( KGlobal::config(), "MainWindow" ) );
+  Toplevel->readProperties( KConfigGroup( KSharedConfig::openConfig(), "MainWindow" ) );
   // setup the statusbar, toolbar etc.
   // Note that this comes after creating the top-level widgets whcih also 
   // sets up the various QActions that the user may have added to the toolbar
@@ -586,4 +589,4 @@ extern "C" Q_DECL_EXPORT int kdemain( int argc, char** argv )
   return result;
 }
 
-#include "ksysguard.moc"
+
